Package: MOMA
Title: Multi Omic Master Regulator Analysis
Version: 1.25.0
Authors@R: c(person("Evan","Paull",email="evanpaull@gmail.com", role=c("aut")), 
              person("Sunny", "Jones", email = "sunnyjjones@gmail.com", 
              role = c("aut", "cre")), person("Mariano", "Alvarez", 
              email = "reef103@gmail.com", role = c("aut")))
Description: This package implements the inference of candidate master regulator
  proteins from multi-omics' data (MOMA) algorithm, 
  as well as ancillary analysis and visualization functions. 
Depends: R (>= 4.0)
License: GPL-3
Encoding: UTF-8
LazyData: true
BugReports: https://github.com/califano-lab/MOMA/issues
RoxygenNote: 7.1.0
biocViews: Software, NetworkEnrichment, NetworkInference, Network,
        FeatureExtraction, Clustering, FunctionalGenomics,
        Transcriptomics, SystemsBiology
Imports: circlize, cluster, ComplexHeatmap, dplyr, ggplot2, graphics,
        grid, grDevices, magrittr, methods, MKmisc,
        MultiAssayExperiment, parallel, qvalue, RColorBrewer, readr,
        reshape2, rlang, stats, stringr, tibble, tidyr, utils
Suggests: BiocStyle, knitr, rmarkdown, testthat, viper
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/MOMA
git_branch: devel
git_last_commit: e936c02
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-07
NeedsCompilation: no
Packaged: 2026-05-07 22:58:03 UTC; biocbuild
Author: Evan Paull [aut],
  Sunny Jones [aut, cre],
  Mariano Alvarez [aut]
Maintainer: Sunny Jones <sunnyjjones@gmail.com>
