% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.r
\docType{data}
\name{mutSig}
\alias{mutSig}
\title{MutSig Blacklisted genes}
\format{
A character vector of Entrez Gene IDs
}
\source{
\url{https://software.broadinstitute.org/cancer/cga/mutsig}
}
\usage{
mutSig
}
\description{
List of genes to not include in the DIGGIT mutation inference because they 
have been found to be mutated more often than expected by chance given 
background mutation processes.
}
\keyword{datasets}
