% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make.interactions.r
\name{getEmpiricalQvals}
\alias{getEmpiricalQvals}
\title{Get empirical qvals}
\usage{
getEmpiricalQvals(test.statistics, null.statistics, alternative = "both")
}
\arguments{
\item{test.statistics}{P-values generated from the test comparisons}

\item{null.statistics}{P-values generated under the null (permutation) model}

\item{alternative}{Optional : 1 or 2 tails used to generate the p-value}
}
\value{
A list with both the qvalues and empirical p-values from the supplied
test and null stats
}
\description{
Get empirical qvals
}
\keyword{internal}
