% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genomic.saturation.r
\name{subsetListInteractions}
\alias{subsetListInteractions}
\title{Helper function: subset a list to the set of keys supplied return the 
names of interactions with positive values, in a list structure}
\usage{
subsetListInteractions(int.l, keys)
}
\arguments{
\item{int.l}{List of interactions, at each index this is a numeric named vector}

\item{keys}{Keys used to reduce interactions}
}
\value{
Returns a filtered list of interactions in the same format as the input
}
\description{
Helper function: subset a list to the set of keys supplied return the 
names of interactions with positive values, in a list structure
}
\keyword{internal}
