% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cluster.r
\name{integrateFunction}
\alias{integrateFunction}
\title{Numerical integration of functions}
\usage{
integrateFunction(f, xmin, xmax, steps = 100, ...)
}
\arguments{
\item{f}{Function of 1 variable (first argument)}

\item{xmin}{Number indicating the min x value}

\item{xmax}{Number indicating the max x value}

\item{steps}{Integer indicating the number of steps to evaluate}

\item{...}{Additional arguments for \code{f}}
}
\value{
Number
}
\description{
Integrates numerically a function over a range using the trapezoid method
}
\keyword{internal}
