% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cluster.r
\name{integrateTZ}
\alias{integrateTZ}
\title{Integration with trapezoid method}
\usage{
integrateTZ(x, y)
}
\arguments{
\item{x}{Numeric vector of x values}

\item{y}{Numeric vector of y values}
}
\value{
Number
}
\description{
This function integrate over a numerical range using the trapezoid method
}
\keyword{internal}
