% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cluster.r
\name{clusterReliability}
\alias{clusterReliability}
\title{Cluster membership reliability estimated by enrichment analysis}
\usage{
clusterReliability(
  cluster,
  similarity,
  xlim = NULL,
  method = c("element", "cluster", "global")
)
}
\arguments{
\item{cluster}{Vector of cluster memberships or list of cluster memberships}

\item{similarity}{Similarity matrix}

\item{xlim}{Optional vector of 2 components indicating the limits for computing AUC}

\item{method}{Character string indicating the mthod to compute reliability, 
either by element, by cluster or global}
}
\value{
Reliability score for each element
}
\description{
This function estimates the cluster membership reliability using aREA
}
\keyword{internal}
